sync-ptr
Sync & Send wrappers for raw pointer’s in rust. To use add “use sync_ptr::*;” to your file, then you should be able to call my_ptr.as_sync_const() among others on any raw pointer to obtain a wrapped version of your raw pointer that is Sync/Send.
Structs
- Send
Const Ptr - Wrapped const raw pointer that is Send but not Sync
- Send
MutPtr - Wrapped mutable raw pointer that is Send but not Sync
- Sync
Const Ptr - Wrapped const raw pointer that is Send+Sync
- Sync
MutPtr - Wrapped mutable raw pointer that is Send+Sync