pub struct SendConstPtr<T>(/* private fields */);Expand description
Wrapped const raw pointer that is Send but not Sync
Implementations
Sourceimpl<T> SendConstPtr<T>
impl<T> SendConstPtr<T>
Sourcepub const fn from_address(addr: usize) -> Self
pub const fn from_address(addr: usize) -> Self
Returns a SendConstPtr from an arbitrary address.
This is equivalent to casting usize as *const T
Sourcepub fn as_address(&self) -> usize
pub fn as_address(&self) -> usize
Returns the address of the pointer.
This is equivalent to casting the pointer using *mut T as usize.
Note
Starting with rust 1.84.0, the pointer itself
has the functions addr and expose_provenance.
These functions should be used instead.
They are available via the deref trait.
This function is roughly equivalent to the expose_provenance function.
Sourcepub const fn cast<Y>(&self) -> SendConstPtr<Y>
pub const fn cast<Y>(&self) -> SendConstPtr<Y>
Casts ptr to another data type while keeping it Send.
Sourcepub const fn as_sync_const(&self) -> SyncConstPtr<T>
pub const fn as_sync_const(&self) -> SyncConstPtr<T>
Makes this ptr Sync
Sourcepub const fn as_send_const(&self) -> Self
pub const fn as_send_const(&self) -> Self
This is equivalent to .clone() and does nothing.
Sourcepub const fn as_sync_mut(&self) -> SyncMutPtr<T>
pub const fn as_sync_mut(&self) -> SyncMutPtr<T>
Sourcepub const fn as_send_mut(&self) -> SendMutPtr<T>
pub const fn as_send_mut(&self) -> SendMutPtr<T>