SendFnPtr

Struct SendFnPtr 

pub struct SendFnPtr<T: Pointer + Copy + Clone + Sized + Eq + PartialEq + PartialOrd + Ord + Hash + Debug>(/* private fields */);

Implementations

Source

impl<T: Pointer + Copy + Clone + Sized + Eq + PartialEq + PartialOrd + Ord + Hash + Debug> SendFnPtr<T>

pub const fn null() -> Self

Constructs a null function pointer

pub const fn inner(&self) -> Option<T>

Returns the inner representation of the wrapper If the option is None then this wrapper was a null pointer.

pub const fn unwrap(&self) -> T

Unwraps the wrapper returning the raw function pointer

Panics

If the wrapper represents a null pointer

pub const fn as_address(&self) -> usize

Returns the address of the function pointer. This is equivalent to doing raw_fn_ptr as usize with the exception that this function will return 0usize for a null pointer.

pub const fn as_raw_ptr(&self) -> *const c_void

Returns the raw pointer representation of the function pointer. This is equivalent to doing raw_fn_ptr as *const c_void with the exception that this function will return null for a null pointer.

pub const fn is_null(&self) -> bool

Returns true if this wrapper represents a null function pointer.